# frozen_string_literal: true

#--
# gravaty
# rubocop:disable Style/AsciiComments
# © 2013 Marco Bresciani
# rubocop:enable Style/AsciiComments
#
# This file is part of gravaty.
#
# gravaty is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# gravaty is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with gravaty. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2013 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative 'constants'

module Gravaty
  # This class is a simple utility that is used to parse and filter
  # parameters for gravaty.
  #
  # Author:: {Marco Bresciani}[mailto:marcobresciani_1974@libero.it]
  # rubocop:disable Style/AsciiComments
  # Copyright:: Copyright © 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020  Marco Bresciani
  # rubocop:enable Style/AsciiComments
  # License:: GNU General Public License version 3
  class Parser
    attr_reader :parsers

    def initialize(args = {})
      @parsers = {}
      ALLOWED_PARAMS.each { |param| parsers[param] = args[param] } unless args.nil?
    end

    # Provides the duck type for a generic parsing object.
    def parse(method = nil, params = nil)
      a_parser = nil
      a_parser = parsers[method.to_sym] unless method.nil? || parsers.nil?
      a_parser&.parse params
    end
  end
end
