# frozen_string_literal: true

#--
# gravaty
# rubocop:disable Style/AsciiComments
# © 2013 Marco Bresciani
# rubocop:enable Style/AsciiComments
#
# This file is part of gravaty.
#
# gravaty is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# gravaty is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with gravaty. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2013 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require 'i18n'

module Gravaty
  # This module is a simple collection of useful things and methods that
  # I prefer to keep as DRYer as possible. Just include it and use the
  # methods...
  #
  # Author:: {Marco Bresciani}[mailto:marcobresciani_1974@libero.it]
  # rubocop:disable Style/AsciiComments
  # Copyright:: Copyright © 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020  Marco Bresciani
  # rubocop:enable Style/AsciiComments
  # License:: GNU General Public License version 3
  module Utils
    # This module contains some utility method to raise errors according
    # to (possibly) common conditions.
    #
    # Author:: {Marco Bresciani}[mailto:marcobresciani_1974@libero.it]
    # rubocop:disable Style/AsciiComments
    # Copyright:: Copyright © 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020  Marco Bresciani
    # rubocop:enable Style/AsciiComments
    # License:: GNU General Public License version 3
    module Raisers
      # Raises an +ArgumentError+ according to parameters, unless the
      # +array+ contains a downcased +value+.
      def raiser_downcase(name = 'error.value', value = nil, array = nil)
        raise ArgumentError, I18n.t(name, value: value) if !value.nil? &&
                                                           !(array.include? value.downcase) &&
                                                           !(array.include? value.downcase)
      end

      # Raises an +ArgumentError+ according to parameters, unless the
      # +array+ contains the number of the +value+.
      def raiser_to_i(name = 'error.value', value = nil, array = nil)
        raise ArgumentError, I18n.t(name, value: value) if !value.nil? &&
                                                           !(array.include? value.to_i) &&
                                                           !(array.include? value.to_i)
      end
    end
  end
end
